@@ -1,6 +1,7 @@
 from dataclasses import dataclass, asdict
+from schema import product
 import dataclasses
-from typing import List, Optional
+from typing import List, Optional, Dict, Union
 import json
 
 
@@ -23,3 +24,12 @@ class EnhancedJSONEncoder(json.JSONEncoder):
         if dataclasses.is_dataclass(o):
             return dataclasses.asdict(o)
         return super().default(o)
+
+
+def package_json_product_list(
+    product_list: List[Dict[str, Union[str, List[float]]]]
+        ) -> List[product.Product]:
+    products: List[product.Product] = [
+        product.Product(**x) for x in product_list  # type: ignore
+    ]
+    return products
